@@ -13,6 +13,7 @@ from tutor.commands import jobs
 from tutor.commands.config import save as config_save_command
 from tutor.commands.context import BaseTaskContext
 from tutor.commands.upgrade.k8s import upgrade_from
+from tutor.commands.upgrade import OPENEDX_RELEASE_NAMES
 from tutor.tasks import BaseTaskRunner
 from tutor.types import Config, get_typed
 
@@ -235,19 +236,6 @@ Press enter when you are ready to continue"""
     )
 
 
-@click.command(help="Configure and run Open edX from scratch")
-@click.option("-I", "--non-interactive", is_flag=True, help="Run non-interactively")
-@click.pass_context
-def quickstart(context: click.Context, non_interactive: bool) -> None:
-    """
-    This command has been renamed to 'launch'.
-    """
-    fmt.echo_alert(
-        "The 'quickstart' command is deprecated and will be removed in a later release. Use 'launch' instead."
-    )
-    context.invoke(launch, non_interactive=non_interactive)
-
-
 @click.command(
     short_help="Run all configured Open edX resources",
     help=(
@@ -461,7 +449,7 @@ def wait(context: K8sContext, name: str) -> None:
 @click.option(
     "--from",
     "from_release",
-    type=click.Choice(["ironwood", "juniper", "koa", "lilac", "maple"]),
+    type=click.Choice(OPENEDX_RELEASE_NAMES),
 )
 @click.pass_context
 def upgrade(context: click.Context, from_release: Optional[str]) -> None:
@@ -474,7 +462,7 @@ def upgrade(context: click.Context, from_release: Optional[str]) -> None:
             "This command only performs a partial upgrade of your Open edX platform. "
             "To perform a full upgrade, you should run `tutor k8s launch`."
         )
-        upgrade_from(context.obj, from_release)
+        upgrade_from(context, from_release)
     # We update the environment to update the version
     context.invoke(config_save_command)
 
@@ -563,7 +551,6 @@ def k8s_namespace(config: Config) -> str:
 
 
 k8s.add_command(launch)
-k8s.add_command(quickstart)
 k8s.add_command(start)
 k8s.add_command(stop)
 k8s.add_command(reboot)
