@@ -10,6 +10,7 @@ from tutor import utils
 from tutor.commands import compose
 from tutor.commands.config import save as config_save_command
 from tutor.commands.upgrade.local import upgrade_from
+from tutor.commands.upgrade import OPENEDX_RELEASE_NAMES
 from tutor.types import Config, get_typed
 
 
@@ -159,28 +160,6 @@ Your Open edX platform is ready and can be accessed at the following urls:
     )
 
 
-@click.command(help="Deprecated alias to 'launch'")
-@compose.mount_option
-@click.option("-I", "--non-interactive", is_flag=True, help="Run non-interactively")
-@click.option("-p", "--pullimages", is_flag=True, help="Update docker images")
-@click.pass_context
-def quickstart(
-    context: click.Context,
-    mounts: t.Tuple[t.List[compose.MountParam.MountType]],
-    non_interactive: bool,
-    pullimages: bool,
-) -> None:
-    """
-    This command has been renamed to 'launch'.
-    """
-    fmt.echo_alert(
-        "The 'quickstart' command is deprecated and will be removed in a later release. Use 'launch' instead."
-    )
-    context.invoke(
-        launch, non_interactive=non_interactive, pullimages=pullimages, mounts=mounts
-    )
-
-
 @click.command(
     short_help="Perform release-specific upgrade tasks",
     help="Perform release-specific upgrade tasks. To perform a full upgrade remember to run `launch`.",
@@ -188,7 +167,7 @@ def quickstart(
 @click.option(
     "--from",
     "from_release",
-    type=click.Choice(["ironwood", "juniper", "koa", "lilac", "maple"]),
+    type=click.Choice(OPENEDX_RELEASE_NAMES),
 )
 @click.pass_context
 def upgrade(context: click.Context, from_release: t.Optional[str]) -> None:
@@ -218,6 +197,5 @@ def _stop_on_dev_start(root: str, config: Config, project_name: str) -> None:
 
 
 local.add_command(launch)
-local.add_command(quickstart)
 local.add_command(upgrade)
 compose.add_commands(local)
