@@ -24,7 +24,11 @@ SESSION_COOKIE_SAMESITE = "Lax"
 # CMS authentication
 IDA_LOGOUT_URI_LIST.append("http://{{ CMS_HOST }}:8001/logout/")
 
-FEATURES['ENABLE_COURSEWARE_MICROFRONTEND'] = False
+FEATURES["ENABLE_COURSEWARE_MICROFRONTEND"] = False
+
+# Disable enterprise integration
+FEATURES["ENABLE_ENTERPRISE_INTEGRATION"] = False
+SYSTEM_WIDE_ROLE_CLASSES.remove("enterprise.SystemWideEnterpriseUserRoleAssignment")
 
 LOGGING["loggers"]["oauth2_provider"] = {
     "handlers": ["console"],
