@@ -21,10 +21,27 @@ OAUTH_ENFORCE_SECURE = False
 # Email settings
 DEFAULT_EMAIL_LOGO_URL = LMS_ROOT_URL + "/theming/asset/images/logo.png"
 BULK_EMAIL_SEND_USING_EDX_ACE = True
+FEATURES["ENABLE_FOOTER_MOBILE_APP_LINKS"] = False
+
+# Branding
+MOBILE_STORE_ACE_URLS = {}
+SOCIAL_MEDIA_FOOTER_ACE_URLS = {}
 
 # Make it possible to hide courses by default from the studio
 SEARCH_SKIP_SHOW_IN_CATALOG_FILTERING = False
 
+# Caching
+CACHES["staticfiles"] = {
+    "KEY_PREFIX": "staticfiles_lms",
+    "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
+    "LOCATION": "staticfiles_lms",
+}
+CACHES["ora2-storage"] = {
+    "KEY_PREFIX": "ora2-storage",
+    "BACKEND": "django_redis.cache.RedisCache",
+    "LOCATION": "redis://{% if REDIS_USERNAME and REDIS_PASSWORD %}{{ REDIS_USERNAME }}:{{ REDIS_PASSWORD }}{% endif %}@{{ REDIS_HOST }}:{{ REDIS_PORT }}/{{ OPENEDX_CACHE_REDIS_DB }}",
+}
+
 # Create folders if necessary
 for folder in [DATA_DIR, LOG_DIR, MEDIA_ROOT, STATIC_ROOT_BASE, ORA2_FILEUPLOAD_ROOT]:
     if not os.path.exists(folder):
